@@ -57,7 +57,7 @@ $contentType = array(
 	'.ccad'		=> 'application/clariscad', // ClarisCAD files
 	'.drw'		 => 'application/drafting', // MATRA Prelude drafting
 	'.dxf'		 => 'application/dxf', // DXF (AutoCAD)
-	'.xl'			=> 'application/excel', // Microsoft Excel
+	'.xls'		=> 'application/excel', // Microsoft Excel
 	'.unv'		 => 'application/i-deas', //SDRC I-DEAS files
 	'.igs'		 => 'application/iges', // IGES graphics format
 	'.iges'		=> 'application/iges', // IGES graphics format
@@ -88,8 +88,8 @@ $contentType = array(
 	'.mif'		 => 'application/x-mif', // FrameMaker MIF Format
 	'.csh'		 => 'application/x-csh', // C-shell script
 	'.dvi'		 => 'application/x-dvi', // TeX DVI
-	'.gz'			=> 'application/x-gzip', // GNU Zip
-	'.gzip'		=> 'application/x-gzip', // GNU Zip
+	'.gz'			=> 'application/gzip', // GNU Zip
+	'.gzip'		=> 'application/gzip', // GNU Zip
 	'.hdf'		 => 'application/x-hdf', // ncSA HDF Data File
 	'.latex'	 => 'application/x-latex', // LaTeX source
 	'.nc'			=> 'application/x-netcdf', // Unidata netCDF
@@ -145,9 +145,6 @@ $contentType = array(
 	'.xpm'	=> 'image/x-xpixmap', // X Pixmap
 	'.xwd'	=> 'image/x-xwindowdump', // X Windows dump (xwd) format
 
-	'.zip'	=> 'multipart/x-zip', // PKZIP Archive
-	'.gzip' => 'multipart/x-gzip', // GNU ZIP Archive
-
 	'.mpeg'	=> 'video/mpeg', // MPEG video
 	'.mpg'	 => 'video/mpeg', // MPEG video
 	'.mpe'	 => 'video/mpeg', // MPEG video
@@ -328,7 +325,7 @@ if (file_exists('include/config.php')) {
 }
 
 // Make sure that the input locale is set up correctly
-setlocale(LC_ALL, '');
+putenv("LANG=".setlocale(LC_ALL, $config->getLocale()));
 
 // assure that a default timezone is set
 if (function_exists('date_default_timezone_get')) {
@@ -385,7 +382,7 @@ $vars['language_form'] = '<form method="get" action="" id="language">'.$hidden;
 $vars['language_select'] = '<select name="language" onchange="javascript:this.form.submit();">';
 foreach ($languages as $code => $names) {
 	$sel = ($code == $language) ? '" selected="selected' : '';
-	$vars['language_select'] .= '<option value="'.$code.$sel.'">'.$names[2].' - '.$names[1].'</option>';
+	$vars['language_select'] .= '<option value="'.$code.$sel.'">'.$names[2].' &ndash; '.$names[1].'</option>';
 }
 $vars['language_select'] .= '</select>';
 $vars['language_submit'] = '<noscript><input type="submit" value="'.$lang['GO'].'" /></noscript>';
@@ -479,7 +476,7 @@ if ($peg === 0)
 $passrev = $rev;
 
 if (!$config->multiViews) {
-	// With MultiViews, wsvn creates the form once the current project is found.
+	// With MultiViews, browse creates the form once the current project is found.
 	createProjectSelectionForm();
 	createRevisionSelectionForm();
 }
@@ -513,7 +510,7 @@ function createProjectSelectionForm() {
 		$options = '<option value="" selected="selected"></option>';
 	}
 	foreach ($config->getRepositories() as $repository) {
-		if ($repository->hasReadAccess('/', true)) {
+		if ($repository->hasReadAccess('/')) {
 			$repoName = $repository->getDisplayName();
 			$sel = ($repoName == $currentRepoName) ? ' selected="selected"' : '';
 			$options .= '<option value="'.escape($repoName).'"'.$sel.'>'.escape($repoName).'</option>';
@@ -562,17 +559,12 @@ function createRevisionSelectionForm() {
 
 function checkSendingAuthHeader($rep = false) {
 	global $config;
-	$auth = null;
+	$authz = null;
 	if ($rep) {
-		$auth =& $rep->getAuth();
+		$authz =& $rep->getAuthz();
 	} else {
-		$auth =& $config->getAuth();
+		$authz =& $config->getAuthz();
 	}
-	$loggedin = $auth->hasUsername();
-	/*if (!$loggedin) {
-		header('WWW-Authenticate: Basic realm="'.str_replace('"', '\"', $auth->getBasicRealm()).'"');
-		header('HTTP/1.x 401 Unauthorized', true, 401);
-	} else {*/
-		header('HTTP/1.x 403 Forbidden', true, 403);
-	//}
+	$loggedin = $authz->hasUsername();
+	http_response_code(403);
 }
